---
name: Feature Request
about: Request a Feature

---

**Describe the Feature**
A clear and concise description of what you would like Tern to do for you.

**Use Cases**
Describe the use case(s) where this feature would be helpful.

**Implementation Changes**
Describe what changes you think would need to happen to the code to implement this feature
```
pseudocode or python code is fine here
```
